@@ -1,10 +1,10 @@
 package Template::Plugin::Unicode;
-$Template::Plugin::Unicode::VERSION = '0.01';
+$Template::Plugin::Unicode::VERSION = '0.02';
 use strict;
 use warnings;
 use base qw/Template::Plugin/;
 
-# ABSTRACT: unicode chars via codepoint
+# ABSTRACT: insert characters via unicode codepoints.
 
 
 sub codepoint2char {
@@ -22,13 +22,14 @@ __END__
 
 =head1 NAME
 
-Template::Plugin::Unicode - unicode chars via codepoint
+Template::Plugin::Unicode - insert characters via unicode codepoints.
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
+
     use Template;
     my $tt = Template->new;
     my $template = '[% USE Unicode %][% Unicode.codepoint2char('0x263A') %]';
@@ -38,16 +39,17 @@ version 0.01
     say $smiley;
 
 =head1 DESCRIPTION
-Insert characters into your text via unicode codepoint.
+
+Insert characters via unicode codepoints.
 
 =head1 SEE ALSO
 
 Another way of inserting characters via unicode codepoints is by
-adding a sub ref to the \%vars hashres passed to process().
+adding a sub ref to the \%vars hashref passed to process().
 
     my $u    = sub { chr(hex($_[0])) };
     my $text = '[% u('0x263a') %]';
-    process(\$text, { u => sub {} }, $output, %options)
+    process(\$text, { u => sub {} }, $output);
 
 =head1 AUTHOR
 
